@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -33,11 +33,14 @@ void LogFile::msgHandler(QtMsgType type, const QMessageLogContext &, const QStri
     if (mainApp->isNoDebugOutput()) return;
   }
 
+  if (!mainApp->dataDirInitialized())
+    return;
+
   QFile file;
   file.setFileName(mainApp->dataDir() + "/debug.log");
   QIODevice::OpenMode openMode = QIODevice::WriteOnly | QIODevice::Text;
 
-  if (file.exists() && (file.size() < maxLogFileSize)) {
+  if (file.exists() && (file.size() < (qint64)maxLogFileSize)) {
     openMode |= QIODevice::Append;
   }
 
@@ -85,7 +88,7 @@ void LogFile::msgHandler(QtMsgType type, const char *msg)
   file.setFileName(mainApp->dataDir() + "/debug.log");
   QIODevice::OpenMode openMode = QIODevice::WriteOnly | QIODevice::Text;
 
-  if (file.exists() && (file.size() < maxLogFileSize)) {
+  if (file.exists() && (file.size() < (qint64)maxLogFileSize)) {
     openMode |= QIODevice::Append;
   }
 
