@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@ MainApplication::MainApplication(int &argc, char **argv)
   , isPortable_(false)
   , isPortableAppsCom_(false)
   , isClosing_(false)
+  , dataDirInitialized_(false)
   , dbFileExists_(false)
   , translator_(0)
   , mainWindow_(0)
@@ -39,6 +40,7 @@ MainApplication::MainApplication(int &argc, char **argv)
   , cookieJar_(0)
   , diskCache_(0)
   , downloadManager_(0)
+  , analytics_(0)
 {
   QString message = arguments().value(1);
   if (isRunning()) {
@@ -61,9 +63,15 @@ MainApplication::MainApplication(int &argc, char **argv)
   setApplicationName("QuiteRss");
   setOrganizationName("QuiteRss");
   setApplicationVersion(STRPRODUCTVER);
-  setWindowIcon(QIcon(":/images/quiterss32"));
+  setWindowIcon(QIcon(":/images/quiterss128"));
   setQuitOnLastWindowClosed(false);
   QSettings::setDefaultFormat(QSettings::IniFormat);
+#if QT_VERSION >= 0x050400
+  QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
+#if QT_VERSION >= 0x050600
+  QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#endif
 
   checkPortable();
 
@@ -77,6 +85,8 @@ MainApplication::MainApplication(int &argc, char **argv)
   setTranslateApplication();
   showSplashScreen();
 
+  createGoogleAnalytics();
+
   connectDatabase();
   setProgressSplashScreen(30);
   qWarning() << "Run application 2";
@@ -155,9 +165,7 @@ void MainApplication::checkPortable()
   isPortable_ = true;
   QString fileName(QCoreApplication::applicationDirPath() + "/portable.dat");
   if (!QFile::exists(fileName)) {
-    fileName = QCoreApplication::applicationDirPath() + "/" + QCoreApplication::applicationName() + ".ini";
-    if (!QFile::exists(fileName))
-      isPortable_ = false;
+    isPortable_ = false;
   }
   if (isPortable_) {
     fileName = QCoreApplication::applicationDirPath() + "/../../QuiteRSSPortable.exe";
@@ -198,6 +206,7 @@ void MainApplication::checkDir()
     QDir dir(dataDir_);
     dir.mkpath(dataDir_);
   }
+  dataDirInitialized_ = true;
 }
 
 void MainApplication::createSettings()
@@ -246,6 +255,22 @@ void MainApplication::createSettings()
   settings.endGroup();
 }
 
+void MainApplication::createGoogleAnalytics()
+{
+  Settings settings;
+  bool statisticsEnabled = settings.value("Settings/statisticsEnabled2", true).toBool();
+  if (statisticsEnabled) {
+    QString clientID;
+    if (!settings.contains("GAnalytics-cid")) {
+      settings.setValue("GAnalytics-cid", QUuid::createUuid().toString());
+    }
+    clientID = settings.value("GAnalytics-cid").toString();
+    analytics_ = new GAnalytics(this, TRACKING_ID, clientID);
+    analytics_->generateUserAgentEtc();
+    analytics_->startSession();
+  }
+}
+
 void MainApplication::connectDatabase()
 {
   QString fileName(dbFileName() % ".bak");
@@ -284,6 +309,12 @@ void MainApplication::quitApplication()
   delete cookieJar_;
   delete closingWidget_;
 
+  if (analytics_) {
+    analytics_->endSession();
+    analytics_->waitForIdle();
+    delete analytics_;
+  }
+
   qWarning() << "Quit application";
 
   quit();
