@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -162,6 +162,8 @@ public:
   QAction *linkedinShareAct_;
   QAction *bloggerShareAct_;
   QAction *printfriendlyShareAct_;
+  QAction *instapaperShareAct_;
+  QAction *redditShareAct_;
   QAction *copyLinkAct_;
   QAction *pageUpWebViewAct_;
   QAction *pageDownWebViewAct_;
@@ -219,9 +221,6 @@ public:
   bool markReadClosingTab_;
   bool markReadMinimize_;
   bool showDescriptionNews_;
-  ENewsClickAction::Type newsSingleClickAction;
-  ENewsClickAction::Type newsDoubleClickAction;
-  ENewsClickAction::Type newsMiddleClickAction;
   bool alternatingRowColorsNews_;
   bool simplifiedDateTime_;
   bool notDeleteStarred_;
@@ -299,11 +298,11 @@ public slots:
   void myEmptyWorkingSet();
   void slotUpdateFeed(int feedId, bool changed, int newCount, bool finish);
   void slotFeedCountsUpdate(FeedCountStruct counts);
-  void slotUpdateNews(int refresh = NewsTabWidget::RefreshInsert);
+  void slotUpdateNews(int refresh);
   void slotUpdateStatus(int feedId, bool changed = true);
   void setNewsFilter(QAction*, bool clicked = true);
   void slotCloseTab(int index);
-  QWebPage *createWebTab(QUrl url = QUrl(), const QString &overrideHtml="");
+  QWebPage *createWebTab(QUrl url = QUrl());
   void feedsModelReload(bool checkFilter = false);
   void setStatusFeed(int feedId, QString status);
   void slotPrint(QWebFrame *frame = 0);
@@ -527,7 +526,9 @@ private:
   int addTab(NewsTabWidget *widget);
 
   NewsModel *newsModel_;
+#ifndef Q_OS_MAC
   QMenu *mainMenu_;
+#endif
   ToolButton *mainMenuButton_;
   TabBar *tabBar_;
   QWidget *tabBarWidget_;
