@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -210,7 +210,6 @@ void ParseObject::slotParse(const QByteArray &xmlData, const int &feedId,
     else {
       while (q.next()) {
         QString str = q.value(2).toString();
-        if (!str.isEmpty()) {
         titleList_.append(str);
 
         str = q.value(1).toString();
@@ -220,7 +219,6 @@ void ParseObject::slotParse(const QByteArray &xmlData, const int &feedId,
         publishedList_.append(str);
         str = q.value(4).toString();
         linkList_.append(str);
-        }
       }
     }
     q.finish();
@@ -293,7 +291,8 @@ void ParseObject::parseAtom(const QString &feedUrl, const QDomDocument &doc)
         }
     }
   }
-  if (QUrl(feedItem.link).host().isEmpty()) {
+
+  if (QUrl(feedItem.link).host().isEmpty() || (QUrl(feedItem.link).host().indexOf('.')) == -1) {
     if (!feedItem.linkBase.isEmpty() && !QUrl(feedItem.linkBase).host().isEmpty())
       feedItem.link = QUrl(feedItem.linkBase).scheme() %  "://" % QUrl(feedItem.linkBase).host();
     else
@@ -428,7 +427,7 @@ void ParseObject::addAtomNewsIntoBase(NewsItemStruct *newsItem)
             if (publishedList_.at(i) == newsItem->updated)
               isDuplicate = true;
           } else {                      // ... or by title
-            if (titleList_.at(i) == newsItem->title)
+            if (!newsItem->title.isEmpty() && (titleList_.at(i) == newsItem->title))
               isDuplicate = true;
           }
         }
@@ -438,7 +437,7 @@ void ParseObject::addAtomNewsIntoBase(NewsItemStruct *newsItem)
         if (publishedList_.at(i) == newsItem->updated)
           isDuplicate = true;
       } else {                              // ... or by title
-        if (titleList_.at(i) == newsItem->title)
+        if (!newsItem->title.isEmpty() && (titleList_.at(i) == newsItem->title))
           isDuplicate = true;
       }
     }
@@ -520,8 +519,13 @@ void ParseObject::parseRss(const QString &feedUrl, const QDomDocument &doc)
   feedItem.title = toPlainText(channel.namedItem("title").toElement().text());
   feedItem.description = channel.namedItem("description").toElement().text();
   feedItem.link = toPlainText(channel.namedItem("link").toElement().text());
-  if (QUrl(feedItem.link).host().isEmpty())
-    feedItem.link = QUrl(feedUrl).scheme() %  "://" % QUrl(feedUrl).host() + feedItem.link;
+  QUrl url = QUrl(feedItem.link);
+  if (url.host().isEmpty())
+    url.setHost(QUrl(feedUrl).host());
+  if (url.scheme().isEmpty())
+    url.setScheme(QUrl(feedUrl).scheme());
+  feedItem.link = url.toString();
+
   feedItem.updated = channel.namedItem("pubDate").toElement().text();
   if (feedItem.updated.isEmpty())
     feedItem.updated = channel.namedItem("pubdate").toElement().text();
@@ -564,8 +568,12 @@ void ParseObject::parseRss(const QString &feedUrl, const QDomDocument &doc)
       if (newsList.item(i).namedItem("guid").toElement().attribute("isPermaLink") == "true")
         newsItem.link = newsItem.id;
     }
-    if (QUrl(newsItem.link).host().isEmpty())
-      newsItem.link = QUrl(feedUrl).scheme() %  "://" % QUrl(feedUrl).host() + newsItem.link;
+    url = QUrl(newsItem.link);
+    if (url.host().isEmpty())
+      url.setHost(QUrl(feedUrl).host());
+    if (url.scheme().isEmpty())
+      url.setScheme(QUrl(feedUrl).scheme());
+    newsItem.link = url.toString();
 
     newsItem.description = newsList.item(i).namedItem("description").toElement().text();
     newsItem.content = newsList.item(i).namedItem("content:encoded").toElement().text();
@@ -624,7 +632,7 @@ void ParseObject::addRssNewsIntoBase(NewsItemStruct *newsItem)
             isDuplicate = true;
           }
         } else {                            // ... or by title
-          if (titleList_.at(i) == newsItem->title)
+          if (!newsItem->title.isEmpty() && (titleList_.at(i) == newsItem->title))
             isDuplicate = true;
         }
       }
@@ -648,7 +656,7 @@ void ParseObject::addRssNewsIntoBase(NewsItemStruct *newsItem)
             isDuplicate = true;
           }
         } else {                            // ... or by title
-          if (titleList_.at(i) == newsItem->title)
+          if (!newsItem->title.isEmpty() && (titleList_.at(i) == newsItem->title))
             isDuplicate = true;
         }
       }
@@ -671,7 +679,7 @@ void ParseObject::addRssNewsIntoBase(NewsItemStruct *newsItem)
           isDuplicate = true;
         }
       } else {                            // ... or by title
-        if (titleList_.at(i) == newsItem->title)
+        if (!newsItem->title.isEmpty() && (titleList_.at(i) == newsItem->title))
           isDuplicate = true;
       }
       if (!isDuplicate) {
