@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -124,8 +124,8 @@ UpdateFeeds::UpdateFeeds(QObject *parent, bool addFeed)
             updateObject_, SLOT(slotNextUpdateFeed(bool)));
     connect(updateObject_, SIGNAL(signalUpdateModel(bool)),
             parent, SLOT(feedsModelReload(bool)));
-    connect(updateObject_, SIGNAL(signalUpdateNews()),
-            parent, SLOT(slotUpdateNews()));
+    connect(updateObject_, SIGNAL(signalUpdateNews(int)),
+            parent, SLOT(slotUpdateNews(int)));
     connect(updateObject_, SIGNAL(signalCountsStatusBar(int,int)),
             parent, SLOT(slotCountsStatusBar(int,int)));
 
@@ -164,7 +164,7 @@ UpdateFeeds::UpdateFeeds(QObject *parent, bool addFeed)
     connect(parent, SIGNAL(signalSetFeedsFilter(bool)),
             updateObject_, SIGNAL(signalSetFeedsFilter(bool)));
     connect(updateObject_, SIGNAL(signalSetFeedsFilter(bool)),
-            parent, SLOT(setFeedsFilter(bool)));
+            parent, SLOT(setFeedsFilter(bool)), Qt::QueuedConnection);
 
     connect(mainApp, SIGNAL(signalSqlQueryExec(QString)),
             updateObject_, SLOT(slotSqlQueryExec(QString)));
@@ -967,8 +967,6 @@ void UpdateObject::slotSetFeedRead(int readType, int feedId, int idException, QL
     slotRecountFeedCounts(feedId);
     slotRecountCategoryCounts();
 
-    emit signalUpdateNews();
-
     if (readType != FeedReadPlaceToTray) {
       slotRefreshInfoTray();
     }
@@ -1164,7 +1162,7 @@ void UpdateObject::slotMarkAllFeedsOld()
   slotRecountCategoryCounts();
 
   if ((mainWindow_->currentNewsTab != NULL) && (mainWindow_->currentNewsTab->type_ < NewsTabWidget::TabTypeWeb)) {
-    emit signalUpdateNews();
+    emit signalUpdateNews(NewsTabWidget::RefreshWithPos);
   }
 
   slotRefreshInfoTray();
