@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include "requestfeed.h"
 #include "parseobject.h"
 #include "faviconobject.h"
+#include "newstabwidget.h"
 
 class UpdateObject;
 class MainWindow;
@@ -108,7 +109,7 @@ signals:
   void setStatusFeed(int feedId, QString status);
   void feedUpdated(int feedId, bool changed, int newCount, bool finish);
   void signalUpdateModel(bool checkFilter = true);
-  void signalUpdateNews();
+  void signalUpdateNews(int refresh = NewsTabWidget::RefreshInsert);
   void signalCountsStatusBar(int unreadCount, int allCount);
   void signalRecountCategoryCounts(QList<int> deletedList, QList<int> starredList,
                                    QList<int> readList, QStringList labelList);
